"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("@gitsync/config");
const git_cli_wrapper_1 = require("git-cli-wrapper");
const log_1 = require("@gitsync/log");
const commit_command_1 = require("@gitsync/commit-command");
let command = {
    handler: () => {
    }
};
command.command = 'post-commit';
command.describe = 'A git hook, use to sync the commits to relative repositories after commit.';
command.handler = async (argv) => {
    if (process.env.GITSYNC_UPDATE) {
        log_1.default.info('Gitsync is updating commit, skipping post commit.');
        return;
    }
    const source = git_cli_wrapper_1.default('.');
    const config = new config_1.Config();
    let prev;
    const revs = await source.run(['rev-list', '-n', '2', '--all']);
    if (!revs) {
        log_1.default.warn('The repository does not have any commits yet.');
        return;
    }
    switch (revs.split('\n').length) {
        case 1:
            // Git empty tree hash
            prev = '4b825dc642cb6eb9a060e54bf8d69288fbee4904';
            break;
        case 2:
            prev = 'HEAD^';
    }
    const result = await source.run(['diff', '--name-only', 'HEAD', prev]);
    log_1.default.info('Found changed files: \n' + result);
    const files = result.split("\n");
    const changedRepos = config.getReposByFiles(files);
    for (const repo of changedRepos) {
        if (repo.squash) {
            log_1.default.info(`Ignore sync squashed repository: ${repo.sourceDir}`);
            continue;
        }
        await runCommand(commit_command_1.default, {
            sourceDir: repo.sourceDir,
            yes: true,
        });
    }
};
async function runCommand(command, options) {
    await command.handler(options);
}
exports.default = command;
